import config from "config";
import client from "lib/client";
import { getRandomInt } from "lib/utils";
import { customContent, createEmbed } from "./embed.components.ts";
import {
    Client,
    EmbedBuilder,
    type Message,
    type CacheType,
    type GuildMember,
    type Interaction,
    type OmitPartialGroupDMChannel,
    type ChatInputCommandInteraction,
} from "discord.js";
import { type CommandsType, Commands } from "commands/index.ts";
import { time } from "drizzle-orm/mysql-core";

export class EmbedService {
    async handleInteraction(interaction: Interaction<CacheType>) {
        if (interaction.isChatInputCommand()) {
            await this.handleChatInputCommand(interaction);
            return;
        }
    }

    async handleChatInputCommand(
        interaction: ChatInputCommandInteraction<CacheType>,
    ) {
        console.log("accept");
        const commandName = interaction.commandName as CommandsType;
        switch (commandName) {
            case Commands.Enum.embed:
                await this.customEmbed(interaction);
                return;
            default:
                break;
        }
    }
    async customEmbed(interaction: ChatInputCommandInteraction<CacheType>) {
        const title = interaction.options.getString("title") || " ";
        const description = interaction.options.getString("description") || " ";
        const timestamp = interaction.options.getBoolean("timestamp") || false;
        // return the value
        console.log(title, description, timestamp);

        // permission check
        const userIdCommand = interaction.user.id;
        if (userIdCommand !== config.discord.myId) {
            await interaction.reply({
                content: "you have no permission for that command",
                ephemeral: true,
            });
            return;
        }
        try {
            // get user id from mentioning
            const guild = interaction.guild;
            if (!guild) {
                await interaction.reply({
                    content: "command can only be used on a server",
                    ephemeral: true,
                });
                return;
            }


            const channels = client.channels;
            const channel = channels.cache.get(interaction.channelId);

            if (channel?.isTextBased() && channel?.isSendable()) {
                await channel.send({
                    embeds: [createEmbed(title, description, timestamp)],
                });
            }
            await interaction.reply({
                content: "done",
                ephemeral: true,
            });
        } catch (error) {
            console.error("Fehler beim Hinzufügen der Rolle:", error);
            await interaction.reply({
                content:
                    "Es gab einen Fehler beim Hinzufügen der Rolle. Stelle sicher, dass du einen gültigen User erwähnt hast.",
                ephemeral: true,
            });
        }
    }
}
